==> dasu_4.11.jar: edu/northwestern/dasu/drools/ReportableFact.java <==
/**
 * Dasu Project
 *
 * File:         ReportableFact.java
 * RCS:          $Id$
 * Description:  ReportableFact class (see below)
 * Author:       Mario Sanchez
 *               Northwestern Systems Research Group
 *               Department of Computer Science
 *               Northwestern University
 * Created:      Sep 24, 2012 at 2:22:53 PM
 * Language:     Java
 * Package:      edu.northwestern.dasu.drools
 * Status:       Experimental (Do Not Distribute)
 *
 * (C) Copyright 2012, Northwestern University, all rights reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */

package edu.northwestern.dasu.drools;

import java.util.HashMap;

/**
 * @author Mario Sanchez &lt;msanchez@eecs.northwestern.edu&gt;
 *
 * The ReportableFact class ...
 */
public class ReportableFact extends FactTemplate  {

	private static final long serialVersionUID = 1L;
	
	public String factType = null;
	public HashMap<String, Object> contentsMap = new HashMap<String, Object>();
	
	public ReportableFact(String factType) {
		this.factType = factType;
	}

	public HashMap<String, Object> getContentsMap() {
		return contentsMap;
	}

	public void setContentsMap(HashMap<String, Object> contentsMap) {
		this.contentsMap = contentsMap;
	}
	
	public String getFactType() {
		return factType;
	}
	
	public void setFactType(String factType) {
		this.factType = factType;
	}
	
	public Object getContentsObject(String name) {
		
		if ( contentsMap.containsKey(name))
			return contentsMap.get(name);
		
		return null;
	}
	
}

==> dasu_5.31.jar: edu/northwestern/dasu/drools/ReportableFact.java <==
/**
 * Dasu Project
 *
 * File:         ReportableFact.java
 * RCS:          $Id$
 * Description:  ReportableFact class (see below)
 * Author:       Mario Sanchez
 *               Northwestern Systems Research Group
 *               Department of Computer Science
 *               Northwestern University
 * Created:      Sep 24, 2012 at 2:22:53 PM
 * Language:     Java
 * Package:      edu.northwestern.dasu.drools
 * Status:       Experimental (Do Not Distribute)
 *
 * (C) Copyright 2012, Northwestern University, all rights reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */

package edu.northwestern.dasu.drools;

import java.util.HashMap;

import edu.northwestern.cs.aqualab.cattle.jsonsimple.JSONObject;

/**
 * @author Mario Sanchez &lt;msanchez@eecs.northwestern.edu&gt;
 *
 * The ReportableFact class ...
 */
public class ReportableFact extends FactTemplate  {

	private static final long serialVersionUID = 3L;
	
	private String factType = null;
	private HashMap<String, Object> contentsMap = new HashMap<String, Object>();
	
	public ReportableFact(String factType) {
		this.factType = factType;
	}

	public void addContentsObject(String label, Object value) {
		contentsMap.put(label, value);
	}
	
	public HashMap<String, Object> getContentsMap() {
		return contentsMap;
	}

	public void setContentsMap(HashMap<String, Object> contentsMap) {
		this.contentsMap = contentsMap;
	}
	
	public String getFactType() {
		return factType;
	}
	
	public void setFactType(String factType) {
		this.factType = factType;
	}
	
	public Object getContentsObject(String label) {
		
		if ( contentsMap.containsKey(label))
			return contentsMap.get(label);
		
		return null;
	}
	
	public JSONObject toJSON() {

		JSONObject json = super.toJSON();		
		for ( String k : contentsMap.keySet() ) {
			json.put(k, contentsMap.get(k));
		}
		return json;
	}
	
}
